### 0.13.1 {small}`2025-08-13`

```{rubric} Features
```
* adds support for `tl.umap` to support `init_pos` in the form of `ndarray`, `paga` or `obsm[key]` {pr}`427` {smaller}`S Dicks`

```{rubric} Performance
```
* speed up `_get_mean_var` for the minor axis of `csx` matrices {pr}`423` {smaller}`S Dicks`
* speed up `gr.co_occurrence` using a `csr`-based scheme {pr}`424` {smaller}`S Dicks`
* speed up `adj_PV` calculation for `decoupler_gpu` {pr}`429` {smaller}`S Dicks`

```{rubric} Bug fixes
```
* Fixes a bug where `decoupler_gpu` would not work for `np.ndarray` {pr}`429` {smaller}`S Dicks`

```{rubric} Misc
```
* refactors `testing_utils` {pr}`427` {smaller}`S Dicks`
* updates to `RAPIDS-25.08` {pr}`428` {smaller}`S Dicks`
* expand documentation on out-of-core workloads and Dask {pr}`432` {smaller}`S Dicks`
